@@ -1,5 +1,5 @@
 var searchData=
 [
   ['questions_0',['Frequently Asked Questions',['../md_docs_2md_2faq.html',1,'']]],
-  ['queues_1',['Named queues',['../md_docs_2md_2signal.html#autotoc_md216',1,'']]]
+  ['queues_1',['Named queues',['../md_docs_2md_2signal.html#named-queues',1,'']]]
 ];
